tblfm

package
v0.9.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 28, 2026 License: Apache-2.0 Imports: 8 Imported by: 1

Documentation

Overview

Package tblfm handles table formulas using Lua for expression evaluation.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Apply

func Apply(
	table [][]string,
	formulas []string,
	opts ...Option,
) (
	resultTable [][]string,
	err error,
)

Apply performs table calculations using TBLFM formulas on the input 2D array and returns the modified table.

Types

type Option

type Option func(*config)

Option is a functional option for Apply.

func WithHeader

func WithHeader(hasHeader bool) Option

WithHeader specifies whether the first row is a header row. Default is true (has header).

func WithIgnoreExit added in v0.9.5

func WithIgnoreExit(ignoreExit bool) Option

WithHeader specifies whether the first row is a header row. Default is true (has header).

type Options added in v0.9.5

type Options []func(*config)

Options is a functional options for Apply.

Jump to