Documentation
¶
Overview ¶
Package tblfm handles table formulas using Lua for expression evaluation.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Option ¶
type Option func(*config)
Option is a functional option for Apply.
func WithHeader ¶
WithHeader specifies whether the first row is a header row. Default is true (has header).
func WithIgnoreExit ¶ added in v0.9.5
WithHeader specifies whether the first row is a header row. Default is true (has header).
Click to show internal directories.
Click to hide internal directories.